==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/DPMContainerExtendedInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.DPMContainerExtendedInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Additional information of the DPMContainer.
 * @property lastRefreshedAt Last refresh time of the DPMContainer.
 */
public data class DPMContainerExtendedInfoArgs(
    public val lastRefreshedAt: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.DPMContainerExtendedInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.DPMContainerExtendedInfoArgs =
        com.pulumi.azurenative.recoveryservices.inputs.DPMContainerExtendedInfoArgs.builder()
            .lastRefreshedAt(lastRefreshedAt?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DPMContainerExtendedInfoArgs].
 */
@PulumiTagMarker
public class DPMContainerExtendedInfoArgsBuilder internal constructor() {
    private var lastRefreshedAt: Output<String>? = null

    /**
     * @param value Last refresh time of the DPMContainer.
     */
    @JvmName("dnbngrawrpfjnkdv")
    public suspend fun lastRefreshedAt(`value`: Output<String>) {
        this.lastRefreshedAt = value
    }

    /**
     * @param value Last refresh time of the DPMContainer.
     */
    @JvmName("oquskxykjoajwtfr")
    public suspend fun lastRefreshedAt(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastRefreshedAt = mapped
    }

    internal fun build(): DPMContainerExtendedInfoArgs = DPMContainerExtendedInfoArgs(
        lastRefreshedAt = lastRefreshedAt,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/DPMContainerExtendedInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.DPMContainerExtendedInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Additional information of the DPMContainer.
 * @property lastRefreshedAt Last refresh time of the DPMContainer.
 */
public data class DPMContainerExtendedInfoArgs(
    public val lastRefreshedAt: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.DPMContainerExtendedInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.DPMContainerExtendedInfoArgs =
        com.pulumi.azurenative.recoveryservices.inputs.DPMContainerExtendedInfoArgs.builder()
            .lastRefreshedAt(lastRefreshedAt?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DPMContainerExtendedInfoArgs].
 */
@PulumiTagMarker
public class DPMContainerExtendedInfoArgsBuilder internal constructor() {
    private var lastRefreshedAt: Output<String>? = null

    /**
     * @param value Last refresh time of the DPMContainer.
     */
    @JvmName("iorceyydmnaiopkm")
    public suspend fun lastRefreshedAt(`value`: Output<String>) {
        this.lastRefreshedAt = value
    }

    /**
     * @param value Last refresh time of the DPMContainer.
     */
    @JvmName("puicngwjthipccwx")
    public suspend fun lastRefreshedAt(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastRefreshedAt = mapped
    }

    internal fun build(): DPMContainerExtendedInfoArgs = DPMContainerExtendedInfoArgs(
        lastRefreshedAt = lastRefreshedAt,
    )
}
